<?php
/**
 * NOTICE OF LICENSE
 *
 * @author    INVERTUS, UAB www.invertus.eu <support@invertus.eu>
 * @copyright Copyright (c) permanent, INVERTUS, UAB
 * @license   Addons PrestaShop license limitation
 * @see       /LICENSE
 *
 * International Registered Trademark & Property of INVERTUS, UAB
 */

use Invertus\SwedBank\Config\Config;
use Invertus\SwedBank\Service\OrderHandler;
use SwedbankPaymentPortal\SharedEntity\Type\PurchaseStatus;
use SwedbankPaymentPortal\SwedbankPaymentPortal;

class SwedBankPayPalConfirmModuleFrontController extends ModuleFrontController
{
    const FILENAME = 'paypalconfirm';
    /**
     * @var SwedBank
     */
    public $module;

    public function postProcess()
    {
        $idLang = $this->context->language->id;
        $idShop = $this->context->shop->id;

        $idOrder = (int)Tools::getValue('id_order');
        $order = new Order($idOrder);

        /** @var OrderHandler $orderService */
        $orderService = $this->module->get(OrderHandler::class);

        /** @var SwedbankPaymentPortal $paymentPortal */
        $paymentPortal = $this->module->get(SwedbankPaymentPortal::class);

        try {
            $idUnique = SwedbankOrderPayment::retrieveUniqueId($idOrder, $idShop);
            $merchantReference = $orderService->getMerchantReference($order, $idUnique);
            $result = $paymentPortal->getPayPalGateway()
                ->handlePendingTransaction($merchantReference);

            if (null === $result) {
                $this->errors[] = $this->module
                    ->l('Operation failed. Please choose another payment method or try again.', self::FILENAME);
                $this->redirectWithNotifications($orderService->getOrderConfirmationUrl($order, $idLang));
            }

            $status = $this->handlePayPalResponse($result->getStatus());
            if (true !== $status) {
                $this->errors[] = $status;
            }

            $params = ['paymentMethod' => Config::PAYMENT_METHOD_PAYPAL];

            if (!empty($this->errors)) {
                $this->redirectWithNotifications($orderService->getOrderConfirmationUrl($order, $idLang, $params));
            }

            Tools::redirect($orderService->getOrderConfirmationUrl($order, $idLang, $params));
        } catch (Exception $e) {
            $debug = (bool) Configuration::get('SB_DEBUG_MODE_'.$this->module->getEnvironment());

            if ($debug) {
                throw $e;
            }

            $this->errors[] = $this->module
                ->l('Operation failed. Please choose another payment method or try again.', self::FILENAME);
            $this->redirectWithNotifications($orderService->getOrderConfirmationUrl($order, $idLang));
        }
    }

    public function checkAccess()
    {
        $idOrder = Tools::getValue('id_order');
        $order = new Order($idOrder);

        $customerAccess = $this->context->customer->id == $order->id_customer;

        if (!Validate::isLoadedObject($order) ||
            !$customerAccess ||
            !$this->module->active ||
            !$this->module->isConfigured()
        ) {
            $this->redirectWithNotifications($this->context->link->getPageLink('404'));
        }

        return true;
    }

    private function handlePayPalResponse(PurchaseStatus $payPalResponseStatus)
    {
        $paymentErrorMessage =
            $this->module->l('Operation failed. Please choose another payment method or try again.', self::FILENAME);

        switch ($payPalResponseStatus) {
            case PurchaseStatus::accepted():
                return true;
            case PurchaseStatus::authenticationFail():
                return $this->module->l('Authentication error', self::FILENAME);
            case PurchaseStatus::HpsMaximumNumberOfRetryTransactionWasBreached():
                return $this->module->l('The maximum number of retry transaction was breached', self::FILENAME);
            case PurchaseStatus::HpsSessionTimedOut():
                return $this->module->l('Your payment session has expired.', self::FILENAME);
            default:
                return $paymentErrorMessage;
        }
    }
}
