<?php
/**
 * NOTICE OF LICENSE
 *
 * @author    INVERTUS, UAB www.invertus.eu <support@invertus.eu>
 * @copyright Copyright (c) permanent, INVERTUS, UAB
 * @license   Addons PrestaShop license limitation
 * @see       /LICENSE
 *
 * International Registered Trademark & Property of INVERTUS, UAB
 */

namespace Invertus\SwedBank\Service;

use DateTime;
use DOMDocument;
use SimpleXMLElement;
use SwedBank;
use SwedbankPaymentPortal\Logger\LoggerInterface;
use SwedbankPaymentPortal\SharedEntity\Type\TransportType;

class Logger implements LoggerInterface
{
    /**
     * @var SwedBank
     */
    private $module;

    public function __construct(SwedBank $module)
    {
        $this->module = $module;
    }

    /**
     * Function to log data.
     *
     * @param string $requestXml
     * @param string $responseXml
     * @param object $requestObject
     * @param object $responseObject
     * @param TransportType $type
     */
    public function logData($requestXml, $responseXml, $requestObject, $responseObject, TransportType $type)
    {
        $requestType = $type->id();
        $request = $this->prettyXml($requestXml);
        $response = $responseXml;

        $now = (new DateTime())->format('Y-m-d H:i:s');
        $logFile = $this->module->getLocalPath().'var/logs/swedbank.log';
        $logData = "\n--- $now ---\n$requestType\n$request\n\n$response\n-----\n";

        file_put_contents($logFile, $logData, FILE_APPEND | LOCK_EX);
    }

    private function prettyXml($xml)
    {
        $doc = new DomDocument('1.0');

        $doc->loadXML($xml);
        $doc->preserveWhiteSpace = false;
        $doc->formatOutput = true;

        $prettyXml = $doc->saveXML();

        return $prettyXml;
    }

    /**
     * function to log only small portion of data
     *
     * @param $type
     * @param $message
     */
    public function logSimpleData($type, $message)
    {
        $xml = new SimpleXMLElement('<xml/>');
        $currentDate = new DateTime();
        $xml->addChild('type', $type);
        $xml->addChild('date', $currentDate->format('Y-m-d H:i:s'));
        $xml->addChild('errorMessage', $message);
        $this->logData(
            $xml->asXML(),
            '',
            null,
            null,
            TransportType::notification()
        );
    }
}
