<?php
/**
 * NOTICE OF LICENSE
 *
 * @author    INVERTUS, UAB www.invertus.eu <support@invertus.eu>
 * @copyright Copyright (c) permanent, INVERTUS, UAB
 * @license   Addons PrestaShop license limitation
 * @see       /LICENSE
 *
 * International Registered Trademark & Property of INVERTUS, UAB
 */

namespace Invertus\SwedBank\Util;

use Customer;
use Invertus\SwedBank\Adapter\Configuration;
use Order;

class OrderValidation
{
    /**
     * @var Configuration
     */
    private $configuration;

    public function __construct(Configuration $configuration)
    {
        $this->configuration = $configuration;
    }

    public function validate(Order $order, Customer $customer)
    {
        $idCurrentState = $order->getCurrentState();
        $paymentContinueStates = $this->configuration->getMultiple([
            'SB_ORDER_STATUS_AWAITING_LIVE',
            'SB_ORDER_STATUS_AWAITING_TEST',
        ]);
        $isValidOrderState = in_array($idCurrentState, $paymentContinueStates);
        $isCurrentCustomerOrder = $order->id_customer == $customer->id;
        $isModulePayment = $order->module == 'swedbank';

        if (!$order->id ||
            !$isValidOrderState ||
            !$isCurrentCustomerOrder ||
            !$isModulePayment ||
            $order->hasBeenPaid()
        ) {
            return false;
        }

        return true;
    }
}
